@@ -2,6 +2,7 @@
 #define MAINWINDOW_H
 
 #include <QtGui>
+#include "bookfinder.h"
 
 class QString;
 class QModelIndex;
@@ -16,7 +17,7 @@ class MainWindow: public QMainWindow
 
 public:
     MainWindow(QWidget *parent = 0);
-    virtual ~MainWindow() {}
+    ~MainWindow();
 
 public slots:
     void showLibrary();
@@ -37,6 +38,7 @@ public slots:
 
 protected:
     virtual void closeEvent(QCloseEvent *event);
+    virtual void timerEvent(QTimerEvent *event);
 
 private:
     void setCurrentBook(const QModelIndex &current);
@@ -59,6 +61,9 @@ private:
     DevTools *devTools;
     QModelIndex mCurrent;
     FullScreenWindow *fullScreenWindow;
+    int preventBlankingTimer;
+    BookFinder *bookFinder;
+    BookFinderThread bookFinderThread;
 };
 
 #endif // MAINWINDOW_H
